==> gatsby-plugin-intl-slug-0.3.11.tgz: package/gatsby-node.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var webpack = require("webpack");

function flattenMessages(nestedMessages, prefix) {
  if (prefix === void 0) {
    prefix = "";
  }

  return Object.keys(nestedMessages).reduce(function (messages, key) {
    var value = nestedMessages[key];
    var prefixedKey = prefix ? prefix + "." + key : key;

    if (typeof value === "string") {
      messages[prefixedKey] = value;
    } else {
      Object.assign(messages, flattenMessages(value, prefixedKey));
    }

    return messages;
  }, {});
}

exports.onCreateWebpackConfig = function (_ref, pluginOptions) {
  var actions = _ref.actions,
      plugins = _ref.plugins;
  var _pluginOptions$redire = pluginOptions.redirectComponent,
      redirectComponent = _pluginOptions$redire === void 0 ? null : _pluginOptions$redire,
      languages = pluginOptions.languages,
      defaultLanguage = pluginOptions.defaultLanguage;

  if (!languages.includes(defaultLanguage)) {
    languages.push(defaultLanguage);
  }

  var regex = new RegExp(languages.map(function (l) {
    return l.split("-")[0];
  }).join("|"));
  actions.setWebpackConfig({
    plugins: [plugins.define({
      GATSBY_INTL_REDIRECT_COMPONENT_PATH: JSON.stringify(redirectComponent)
    }), new webpack.ContextReplacementPlugin(/@formatjs[/\\]intl-relativetimeformat[/\\]dist[/\\]locale-data$/, regex), new webpack.ContextReplacementPlugin(/@formatjs[/\\]intl-pluralrules[/\\]dist[/\\]locale-data$/, regex)]
  });
};

exports.onCreatePage =
/*#__PURE__*/
function () {
  var _ref2 = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee(_ref3, pluginOptions) {
    var page, actions, createPage, deletePage, _pluginOptions$path, path, _pluginOptions$langua, languages, _pluginOptions$defaul, defaultLanguage, _pluginOptions$redire2, redirect, getMessages, getSlugs, generatePage, newPage;

    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            page = _ref3.page, actions = _ref3.actions;

            if (!(typeof page.context.intl === "object")) {
              _context.next = 3;
              break;
            }

            return _context.abrupt("return");

          case 3:
            createPage = actions.createPage, deletePage = actions.deletePage;
            _pluginOptions$path = pluginOptions.path, path = _pluginOptions$path === void 0 ? "." : _pluginOptions$path, _pluginOptions$langua = pluginOptions.languages, languages = _pluginOptions$langua === void 0 ? ["en"] : _pluginOptions$langua, _pluginOptions$defaul = pluginOptions.defaultLanguage, defaultLanguage = _pluginOptions$defaul === void 0 ? "en" : _pluginOptions$defaul, _pluginOptions$redire2 = pluginOptions.redirect, redirect = _pluginOptions$redire2 === void 0 ? false : _pluginOptions$redire2;

            getMessages = function getMessages(path, language) {
              try {
                // TODO load yaml here
                var messages = require(path + "/" + language + ".json");

                return flattenMessages(messages);
              } catch (error) {
                if (error.code === "MODULE_NOT_FOUND") {
                  process.env.NODE_ENV !== "test" && console.error("[gatsby-plugin-intl] couldn't find file \"" + path + "/" + language + ".json\"");
                }

                throw error;
              }
            }; // Return all languages slug for this page


            getSlugs = function getSlugs(path) {
              var currentPage = path.includes('tags') ? page.path : page.path.replace(/\//, ""); // Denna rad krånglar till det!

              var slugs = {};
              languages.forEach(function (language) {
                var messages = getMessages(path, language);
                slugs[language] = messages[currentPage + ".slug"] ? "/" + messages[currentPage + '.slug'] : "/" + currentPage;
              });
              return slugs;
            };

            generatePage = function generatePage(routed, language) {
              var messages = getMessages(path, language);
              var slugs = getSlugs(path);
              var newPath = routed ? "/" + language + slugs[language] : "" + slugs[language];
              return (0, _extends2.default)({}, page, {
                path: newPath,
                context: (0, _extends2.default)({}, page.context, {
                  language: language,
                  intl: {
                    language: language,
                    languages: languages,
                    slugs: slugs,
                    messages: messages,
                    routed: routed,
                    originalPath: page.path,
                    redirect: redirect,
                    defaultLanguage: defaultLanguage
                  }
                })
              });
            };

            newPage = generatePage(false, defaultLanguage);
            deletePage(page);
            createPage(newPage);
            languages.forEach(function (language) {
              var localePage = generatePage(true, language);
              var regexp = new RegExp("/404/?$");

              if (regexp.test(localePage.path)) {
                localePage.matchPath = "/" + language + "/*";
              }

              createPage(localePage);
            });

          case 12:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function (_x, _x2) {
    return _ref2.apply(this, arguments);
  };
}();

==> gatsby-plugin-intl-slug-0.3.12.tgz: package/gatsby-node.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var webpack = require("webpack");

function flattenMessages(nestedMessages, prefix) {
  if (prefix === void 0) {
    prefix = "";
  }

  return Object.keys(nestedMessages).reduce(function (messages, key) {
    var value = nestedMessages[key];
    var prefixedKey = prefix ? prefix + "." + key : key;

    if (typeof value === "string") {
      messages[prefixedKey] = value;
    } else {
      Object.assign(messages, flattenMessages(value, prefixedKey));
    }

    return messages;
  }, {});
}

exports.onCreateWebpackConfig = function (_ref, pluginOptions) {
  var actions = _ref.actions,
      plugins = _ref.plugins;
  var _pluginOptions$redire = pluginOptions.redirectComponent,
      redirectComponent = _pluginOptions$redire === void 0 ? null : _pluginOptions$redire,
      languages = pluginOptions.languages,
      defaultLanguage = pluginOptions.defaultLanguage;

  if (!languages.includes(defaultLanguage)) {
    languages.push(defaultLanguage);
  }

  var regex = new RegExp(languages.map(function (l) {
    return l.split("-")[0];
  }).join("|"));
  actions.setWebpackConfig({
    plugins: [plugins.define({
      GATSBY_INTL_REDIRECT_COMPONENT_PATH: JSON.stringify(redirectComponent)
    }), new webpack.ContextReplacementPlugin(/@formatjs[/\\]intl-relativetimeformat[/\\]dist[/\\]locale-data$/, regex), new webpack.ContextReplacementPlugin(/@formatjs[/\\]intl-pluralrules[/\\]dist[/\\]locale-data$/, regex)]
  });
};

exports.onCreatePage =
/*#__PURE__*/
function () {
  var _ref2 = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee(_ref3, pluginOptions) {
    var page, actions, createPage, deletePage, _pluginOptions$path, path, _pluginOptions$langua, languages, _pluginOptions$defaul, defaultLanguage, _pluginOptions$redire2, redirect, getMessages, getSlugs, generatePage, newPage;

    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            page = _ref3.page, actions = _ref3.actions;

            if (!(typeof page.context.intl === "object")) {
              _context.next = 3;
              break;
            }

            return _context.abrupt("return");

          case 3:
            createPage = actions.createPage, deletePage = actions.deletePage;
            _pluginOptions$path = pluginOptions.path, path = _pluginOptions$path === void 0 ? "." : _pluginOptions$path, _pluginOptions$langua = pluginOptions.languages, languages = _pluginOptions$langua === void 0 ? ["en"] : _pluginOptions$langua, _pluginOptions$defaul = pluginOptions.defaultLanguage, defaultLanguage = _pluginOptions$defaul === void 0 ? "en" : _pluginOptions$defaul, _pluginOptions$redire2 = pluginOptions.redirect, redirect = _pluginOptions$redire2 === void 0 ? false : _pluginOptions$redire2;

            getMessages = function getMessages(path, language) {
              try {
                // TODO load yaml here
                var messages = require(path + "/" + language + ".json");

                return flattenMessages(messages);
              } catch (error) {
                if (error.code === "MODULE_NOT_FOUND") {
                  process.env.NODE_ENV !== "test" && console.error("[gatsby-plugin-intl] couldn't find file \"" + path + "/" + language + ".json\"");
                }

                throw error;
              }
            }; // Return all languages slug for this page


            getSlugs = function getSlugs(path) {
              var currentPage = page.path.replace(/\//g, ""); // Denna rad krånglar till det!

              var slugs = {};
              languages.forEach(function (language) {
                var messages = getMessages(path, language);
                slugs[language] = messages[currentPage + ".slug"] ? "/" + messages[currentPage + '.slug'] : "/" + currentPage;
              });
              console.log('page: ' + page);
              console.log('path: ' + path);
              console.log('page path: ' + page.path);
              console.log('slugs: ' + slugs);
              return slugs;
            };

            generatePage = function generatePage(routed, language) {
              var messages = getMessages(path, language);
              var slugs = getSlugs(path);
              var newPath = routed ? "/" + language + slugs[language] : "" + slugs[language];
              return (0, _extends2.default)({}, page, {
                path: newPath,
                context: (0, _extends2.default)({}, page.context, {
                  language: language,
                  intl: {
                    language: language,
                    languages: languages,
                    slugs: slugs,
                    messages: messages,
                    routed: routed,
                    originalPath: page.path,
                    redirect: redirect,
                    defaultLanguage: defaultLanguage
                  }
                })
              });
            };

            newPage = generatePage(false, defaultLanguage);
            deletePage(page);
            createPage(newPage);
            languages.forEach(function (language) {
              var localePage = generatePage(true, language);
              var regexp = new RegExp("/404/?$");

              if (regexp.test(localePage.path)) {
                localePage.matchPath = "/" + language + "/*";
              }

              createPage(localePage);
            });

          case 12:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function (_x, _x2) {
    return _ref2.apply(this, arguments);
  };
}();
